% Estimate CRRA parameters using Jakiela-Ozier (2015) data
% Estimates the following parameters:  
%   rho, SD of rho, sigma (variance of the logit noise param)
% Written by PJ & OWO

clear all

global T 
global B W Q T K D 
global NDRAWS SEED1
global cp ct cp1 cp2 cp3 cp4 cp5 cp6 
global NP NP1 NP2 NP3 NP4 NP5 NP6 
global cb1 cb2 cb3 cb4 cb5 cb6 
global cep3 cep6 ch3 ch6 ce3 ce6 
global DR1 DR2 DR3 DR4 DR5 DR6 
global rho1 rho2 rho3 rho4 rho5 rho6 
global d1 d2 d3 d4 d5 d6 
global KR2 KR3 KR5 KR6 
global XSMALL XLARGE
global X1 X2 X3N X3A X3H X4 X5 X6A X6N X6H
global P3 P6 NEG3 NEG6
global H4 H5 H6 H6B H100
global EXITDATA ESTKAPPA LINTAU
global TMAT2 TMAT3 TMAT5 TMAT6 tsize psize
global reallysmall reallybig
global estIndicators estBetahat estSEhat estNames

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DATA ORGANIZATION 

XMAT=load('rivemenALL.csv'); 
%XMAT=load('rivewomenALL.csv'); 
NDRAWS=2000; 
SEED1 = 12345; 
randn('state',SEED1) 
rand('state',SEED1)  

cp=XMAT(:,1); 
NP=cp(end,1); 
ct=XMAT(:,2); 
for i=1:6  
    eval(['cp' num2str(i) '=XMAT(ct==i,1);']) 
    eval(['NP' num2str(i) '=size(cp' num2str(i) ',1);'])
    eval(['cb' num2str(i) '=XMAT(ct==i,3);']) 
    eval(['cep' num2str(i) '=XMAT(ct==i,4);']) 
    eval(['ch' num2str(i) '=XMAT(ct==i,5);']) 
    eval(['ce' num2str(i) '=XMAT(ct==i,6);']) 
    eval(['DR' num2str(i) '=randn(1,NP'  num2str(i) ',NDRAWS); ']) 
end

reallysmall=1/1000000;
reallybig=1000000;

XSMALL=linspace(0,80,9); 
XSMALL=[XSMALL' XSMALL']; 
XSMALL(:,1)=80.-XSMALL(:,1); 
XSMALL(9,1)=reallysmall; 
XSMALL(:,2)=80.+4.*XSMALL(:,2); 
XSMALL=reshape(XSMALL,9,2,1,1); 

XLARGE=linspace(0,180,19); 
XLARGE=[XLARGE' XLARGE'];
XLARGE(:,1)=180.-XLARGE(:,1);
XLARGE(19,1)=reallysmall;
XLARGE(:,2)=180.+4.*XLARGE(:,2);
XLARGE=reshape(XLARGE,19,2,1,1); 

H100=zeros(19,2); 
H100(1:9,:)=100; 
H100=reshape(H100,19,2,1,1);

X1=repmat(XSMALL,[1,1,NP1,NDRAWS]); % Make NP1xNDRAWS copies of possible payouts
X4=repmat(XLARGE,[1,1,NP4,NDRAWS]); % Make NP4xNDRAWS copies of possible payouts

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ESTIMATION 

T=[ 1 ; 4 ];

% Starting values 
B=[ 0.6 ]; 
W=[ 0.3 ]; 
Q=[ 0.04 ]; 
param=[B;W;Q]; 

MAXITERS=[]; 
PARAMTOL=0.0000000000001; 
LLTOL=0.00001; 

% OPTION 1:  UTILITY SCALING USED IN PAPER 
%options=optimset('LargeScale','off','Display','iter','GradObj','off',...
%    'MaxFunEvals',10000,'MaxIter',MAXITERS,'TolX',PARAMTOL,'TolFun',LLTOL,'DerivativeCheck','off');
%[paramhat,fval,exitflag,output,grad,hessian]=fminunc(@llapptable13col1,param,options);

% OPTION 2:  STANDARD (1-RHO) UTILITY SCALING 
options=optimset('LargeScale','off','Display','iter','GradObj','off',...
    'MaxFunEvals',10000,'MaxIter',MAXITERS,'TolX',PARAMTOL,'TolFun',LLTOL,'DerivativeCheck','off');
[paramhat,fval,exitflag,output,grad,hessian]=fminunc(@llapptable13col2,param,options);

% OPTION 3:  CERTAINTY EQUIVALENTS
%options=optimset('LargeScale','off','Display','iter','GradObj','off',...
%    'MaxFunEvals',10000,'MaxIter',MAXITERS,'TolX',PARAMTOL,'TolFun',LLTOL,'DerivativeCheck','off');
%[paramhat,fval,exitflag,output,grad,hessian]=fminunc(@llapptable13col3,param,options);

% OPTION 4:  CONTEXTUAL UTILITY
%options=optimset('LargeScale','off','Display','iter','GradObj','off',...
%    'MaxFunEvals',10000,'MaxIter',MAXITERS,'TolX',PARAMTOL,'TolFun',LLTOL,'DerivativeCheck','off');
%[paramhat,fval,exitflag,output,grad,hessian]=fminunc(@llapptable13col4,param,options);

ihess=inv(hessian);
stderr=sqrt(diag(ihess));
paramhat(2,1)=abs(paramhat(2,1));


